# Python Package Template

## Description
A simple demo of how to structure and use a Python package

## Installation
```bash
python3 -m pip install --index-url https://test.pypi.org/simple/ example-package-samreynoldsmath
```

## License
[MIT](https://choosealicense.com/licenses/mit/)
